pub trait ProcBoolMethodExt: Sized {
// Required method
fn from_fn<T: IProcInst>(
target: T,
callback: extern "C" fn(T, OptionalMethod) -> bool,
) -> Option<Self>;
}Required Methods
Sourcefn from_fn<T: IProcInst>(
target: T,
callback: extern "C" fn(T, OptionalMethod) -> bool,
) -> Option<Self>
fn from_fn<T: IProcInst>( target: T, callback: extern "C" fn(T, OptionalMethod) -> bool, ) -> Option<Self>
Bind target and call callback on it (returning bool). Like ProcVoidMethod, Invoke() takes
no VM argument, so the bound target is the only object the callback sees. The callback’s first
parameter is forced to the same type as target.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.